##  Concatenating To-Dos Sequentially
This video tutorial shows how to concatenate multiple to-dos created by automations sequentially. This ensures that a new to-do is only created after the previous one has been marked as complete.
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_v8bio3vh/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Fautomation-examples-selected-use-cases%3Fversion%3DCLOUD)
